{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      ./voip.nix
    ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "yate";

  boot.kernel.sysctl = {
    "net.ipv4.conf.all.forwarding" = true;
    "net.ipv6.conf.all.forwarding" = true;
  };

  networking.useNetworkd = true;
  services.resolved.dnssec = "false";
  systemd.network = {
    networks."10-ens18" = {
      matchConfig = {
        Name = "ens18";
      };
      address = [
        "10.42.10.6/24"
        "2a01:4f8:1c0c:8221::6/64"
      ];
      gateway = [
        "10.42.10.1"
        "2a01:4f8:1c0c:8221::1"
      ];
      dns = [
        "10.42.10.8"
        "2a01:4f8:1c0c:8221::8"
      ];
    };

    links."20-vlan132" = {
      matchConfig.MACAddress = "4e:9e:f3:3e:ed:36";
      linkConfig.Name = "vlan132";
    };
    networks."20-vlan132" = {
      matchConfig = {
        Name = "vlan132";
      };
      address = [ "10.42.132.1/24" ];
    };

    links."20-vlan133" = {
      matchConfig.MACAddress = "86:3c:c7:51:c4:82";
      linkConfig.Name = "vlan133";
    };
    networks."20-vlan133" = {
      matchConfig = {
        Name = "vlan133";
      };
      address = [ "10.42.133.1/24" ];
    };
  };

  services.kea.dhcp4 = {
    settings = {
      interfaces-config = {
        interfaces = [ "vlan133" ];
      };
      subnet4 = [
        {
          id = 133;
          subnet = "10.42.133.1/24";
          pools = [
            {
              pool = "10.42.133.100 - 10.42.133.240";
            }
          ];
          option-data = [
            {
              name = "routers";
              data = "10.42.133.1";
            }
            {
              name = "domain-name-servers";
              data = "10.42.10.8";
            }
          ];
        }
      ];
    };
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

}
